/*
    Read preferences

    Changelog:
    
    1.12.2020: More robustness, new AWTSELECTOR pref
    1.12.2020: Let's look for prefs.txt elsewhere too (home dir at least)
    6.5.2016: Added ERRORCOLOR
    29.4.2016: Added UIGAP
    27.4.2016: GRID setting for prefs
    27.4.2016: Aspect ratio (aspect/ASPECT) added, ILLEGAL for illegal colors
    26.4.2016: The first version
*/

final int PAL=0,
          NTSC=1,
          SQUARE=2;
          
final int ILLEGAL=1; //Impossible #RGB value (no alpha)

class Preferences
{
    int       zoom=2,
              aspect=PAL,
              errorcolor=ILLEGAL,
              awtselector=-1; // Use AWT's file dialog instead of JFileChooser, -1 = platform default
    
    final int BWIDTH=21,            // Border width
              UIWIDTH=134,
              UICOLOR=#445060,
              UITEXT=#e0e0e0,
              UIROW=25,             // Button or text row height
              UIGAP=8,              // A gap
              MESSAGEDURATION=60*3; // How many frames messages last
              
    boolean   grid=false;
    
    String    path="",              // Default paths for files
              filename="unnamed";
    
    Preferences()
    {
    }
    
    // Read the preferences file
    void readprefs(String namn)
    {
        String row[]=loadStrings(namn);
        
        if(row==null) // Let's retry elsewhere
        {
            row=loadStrings(System.getProperty("user.home")+File.separator+namn);

            if(row==null)
                row=loadStrings(sketchPath("")+namn);
        }
        
        if(row==null)
            return;
            
        for(int i=0;i<row.length;i++) // Parse each line
        {
            if(row[i].length()>1)
            {
                String s[]=split(row[i],"=");
                
                if(s[0].equals("ZOOM") && s.length>1)
                {
                    zoom=int(s[1]);
                    if(zoom<1)
                        zoom=2;
                }
                if(s[0].equals("GRID") && s.length>1)
                {
                    grid=int(s[1])==1;
                }
                if(s[0].equals("ASPECT") && s.length>1)
                {
                    if(s[1].equals("PAL")) aspect=PAL;
                    if(s[1].equals("NTSC")) aspect=NTSC;
                    if(s[1].equals("SQUARE")) aspect=SQUARE;
                }
                if(s[0].equals("PATH") && s.length>1)
                {
                    path=s[1];
                    message("Default path: "+path);
                }
                if(s[0].equals("ERRORCOLOR") && s.length>1)
                {
                    if(!s[1].equals(""))
                    {
                        errorcolor=unhex(s[1]);
                        if(errorcolor<0 || errorcolor>=256*256*256) // Garbage
                            errorcolor=ILLEGAL;
                        else
                            errorcolor|=0xff000000; // Alpha
                    }
                }
                if(s[0].equals("AWTSELECTOR") && s.length>1) // Use AWT's fileselector instead of Swing's
                {
                    if(s[1].equals("1"))
                        awtselector=1;
                    if(s[1].equals("0"))
                        awtselector=0;
                }
            }
        }
    }
}
